@@ -62,11 +62,6 @@ export const config: Configuration = {
     electronDownload: {
         cache: ".cache",
     },
-
-    flatpak: {
-        baseVersion: "24.08",
-        runtimeVersion: "24.08",
-    },
 };
 
 export default config;
