@@ -7,8 +7,10 @@ export let firstRun: boolean;
 const defaults: Settings = {
     windowStyle: "default",
     channel: "stable",
+    bounceOnPing: false,
     legcordCSP: true,
     minimizeToTray: true,
+    overlayButtonColor: "#121214",
     keybinds: [],
     audio: {
         workaround: false,
@@ -177,3 +179,7 @@ export function setup(): void {
         ...defaults,
     });
 }
+
+export function setFirstRun(value: boolean): void {
+    firstRun = value;
+}
