@@ -1,11 +1,6 @@
 import { readFileSync } from "node:fs";
 import os from "node:os";
 import path from "node:path";
-import RPCServer from "arrpc";
-// To allow seamless switching between custom titlebar and native os titlebar,
-// I had to add most of the window creation code here to split both into separate functions
-// WHY? Because I can't use the same code for both due to annoying bug with value `frame` not responding to variables
-// I'm sorry for this mess but I'm not sure how to fix it.
 import {
     BrowserWindow,
     type BrowserWindowConstructorOptions,
@@ -14,6 +9,7 @@ import {
     dialog,
     nativeImage,
     shell,
+    utilityProcess,
 } from "electron";
 import contextMenu from "electron-context-menu";
 import { firstRun, getConfig, setConfig } from "../common/config.js";
@@ -173,12 +169,18 @@ function doAfterDefiningTheWindow(passedWindow: BrowserWindow): void {
 
     registerCustomHandler();
 
-    passedWindow.webContents.session.webRequest.onBeforeRequest(
-        {
-            urls: ["https://*/api/v*/science", "https://sentry.io/*", "https://*.nel.cloudflare.com/*"],
-        },
-        (_, callback) => callback({ cancel: true }),
-    );
+    const blockedPatterns = [
+        /https:\/\/.*\/api\/v\d+\/science/,
+        /https:\/\/sentry\.io\/.*/,
+        /https:\/\/.*\.nel\.cloudflare\.com\/.*/,
+    ];
+    passedWindow.webContents.session.webRequest.onBeforeRequest((details, callback) => {
+        if (blockedPatterns.some((pattern) => pattern.test(details.url))) {
+            return callback({ cancel: true });
+        }
+        return callback({});
+    });
+
     // fix UMG video playback
     passedWindow.webContents.session.webRequest.onBeforeSendHeaders(
         { urls: ["https://www.youtube.com/embed/*"] },
@@ -236,8 +238,11 @@ function doAfterDefiningTheWindow(passedWindow: BrowserWindow): void {
             passedWindow.setOverlayIcon(null, "");
         }
         if (process.platform === "darwin") {
-            if (title.startsWith("•")) return app.dock.setBadge("•");
-            if (title.startsWith("(")) return app.setBadgeCount(Number.parseInt(/\((\d+)\)/.exec(title)![1]));
+            if (title.startsWith("•")) return app.dock?.setBadge("•");
+            if (title.startsWith("(")) {
+                if (getConfig("bounceOnPing")) app.dock?.bounce();
+                return app.setBadgeCount(Number.parseInt(/\((\d+)\)/.exec(title)![1]));
+            }
             app.setBadgeCount(0);
         }
         if (!title.endsWith(legcordSuffix)) {
@@ -290,12 +295,27 @@ function doAfterDefiningTheWindow(passedWindow: BrowserWindow): void {
         void passedWindow.webContents.executeJavaScript(`document.body.removeAttribute("isMaximized");`);
     });
     if (getConfig("inviteWebsocket") && mainWindows.length === 1) {
-        const RPC = new RPCServer();
+        const child = utilityProcess.fork(path.join(import.meta.dirname, "rpc.js"));
 
-        RPC.on("activity", (data: string) => passedWindow.webContents.send("rpc", data));
-        RPC.on("invite", (code: string) => {
-            console.log(code);
-            createInviteWindow(code);
+        child.on("spawn", () => {
+            console.log("arRPC process started");
+            console.log(child.pid);
+        });
+
+        child.on("message", (message) => {
+            const json = JSON.parse(message);
+            if (json.type === "invite") {
+                createInviteWindow(json.code);
+            } else if (json.type === "activity") {
+                console.log("activity pulse");
+                console.log(json.data);
+                passedWindow.webContents.send("rpc", json.data);
+            }
+        });
+
+        child.on("exit", () => {
+            console.log("arRPC process exited");
+            console.log(child.pid);
         });
     }
     if (firstRun) {
@@ -352,12 +372,12 @@ export function createWindow() {
         case "overlay":
             browserWindowOptions.titleBarStyle = "hidden";
             browserWindowOptions.titleBarOverlay = {
-                color: "#2c2f33",
+                color: getConfig("overlayButtonColor"),
                 symbolColor: "#99aab5",
-                height: 30,
+                height: 36,
             };
             browserWindowOptions.trafficLightPosition = {
-                x: 13,
+                x: 10,
                 y: 10,
             };
             break;
@@ -368,10 +388,16 @@ export function createWindow() {
             browserWindowOptions.transparent = true;
             break;
         case "modern":
-            browserWindowOptions.backgroundColor = "#00000000";
-            browserWindowOptions.transparent = false;
-            browserWindowOptions.frame = true;
-            browserWindowOptions.backgroundMaterial = "acrylic";
+            if (os.platform() === "win32") {
+                browserWindowOptions.backgroundColor = "#00000000";
+                browserWindowOptions.transparent = false;
+                browserWindowOptions.frame = true;
+                browserWindowOptions.backgroundMaterial = "acrylic";
+            } else if (os.platform() === "darwin") {
+                browserWindowOptions.backgroundColor = "#00000000";
+                browserWindowOptions.vibrancy = "fullscreen-ui";
+                browserWindowOptions.transparent = true;
+            }
             break;
         case "none":
             break;
