@@ -62,9 +62,8 @@ export function SettingsPage() {
             >
                 <option value="default">{store.i18n["settings-theme-default"]}</option>
                 <option value="native">{store.i18n["settings-theme-native"]}</option>
-                <Show when={window.legcord.platform === "win32" || "darwin"}>
-                    <option value="overlay">{store.i18n["settings-theme-overlay"]}</option>
-                </Show>
+                <option value="overlay">{store.i18n["settings-theme-overlay"]}</option>
+                <option value="legacy">Legacy</option>
             </DropdownItem>
             <DropdownItem
                 value={store.settings.transparency}
@@ -76,7 +75,7 @@ export function SettingsPage() {
                 link="https://github.com/Legcord/Legcord/wiki/Transparency-options"
             >
                 <option value="universal">{store.i18n["settings-transparency-universal"]}</option>
-                <Show when={window.legcord.platform === "win32"}>
+                <Show when={window.legcord.platform === "win32" || window.legcord.platform === "darwin"}>
                     <option value="modern">{store.i18n["settings-transparency-modern"]}</option>
                 </Show>
                 <option value="none">{store.i18n["settings-none"]}</option>
@@ -90,6 +89,15 @@ export function SettingsPage() {
                     {store.i18n["settings-autoHideMenuBar"]}
                 </SwitchItem>
             </Show>
+            <Show when={window.legcord.platform === "darwin"}>
+                <SwitchItem
+                    note={store.i18n["settings-bounceOnPing-desc"]}
+                    value={settings.bounceOnPing}
+                    onChange={(e: boolean) => setConfig("bounceOnPing", e, true)}
+                >
+                    {store.i18n["settings-bounceOnPing"]}
+                </SwitchItem>
+            </Show>
             <DropdownItem
                 value={settings.tray}
                 onChange={(e) => setConfig("tray", (e.target as HTMLInputElement).value as Settings["tray"], true)}
